﻿Type.registerNamespace("Jeffz.UI");

Jeffz.UI.CultureSelector = function(associatedElement)
{
    Jeffz.UI.CultureSelector.initializeBase(this, [associatedElement]);
	
	var _culture = "en-US";
	var _isLoading = false;
	var _selectionChangedHandler;
	var _loadCompleteHander;
	
	this.get_culture = function()
	{
        return _culture;
    }
    
    this.set_culture = function(value)
    {
		if (!this.get_isInitialized())
		{
			_culture = value;
			return;
		}
    
		if (_culture == value)
		{
			return;
		}
		
		var cancelArgs = new Sys.CultureCancelEventArgs(value);
        this.cultureChanging.invoke(this, cancelArgs);
        canceled = cancelArgs.get_canceled();
        
        if (!canceled)
        {
			_culture = value;
			this.__updateCulture();
			this.raisePropertyChanged('culture');
        }
        
		this.__changeSelectedOption(_culture);
    }
    
    this.get_isLoading = function()
    {
		return _isLoading;
    }
    
    this.cultureChanging = new Type.Event(this);
    
	this.getDescriptor = function()
	{
		var td = Jeffz.UI.CultureSelector.callBaseMethod(this, 'getDescriptor');
		
		td.addProperty("culture", String);
		td.addProperty("isLoading", Boolean, true);
		td.addEvent("cultureChanging", true);
		
		return td;
    }
    Jeffz.UI.CultureSelector.registerBaseMethod(this, 'getDescriptor');
    
    this.initialize = function()
    {
		Jeffz.UI.CultureSelector.callBaseMethod(this, 'initialize');

		while (this.element.options.length > 0)
		{
			this.element.options.remove(0);
		}
		
		var cultures = ["en-US", "zh-CN", "fr-FR", "ko-KR"];
		for (var i = 0; i < cultures.length; i++)
		{
			var option = document.createElement("option");
			option.text = cultures[i];
			option.value = cultures[i];
			this.element.options.add(option);
		}
		
		_selectionChangedHandler = Function.createDelegate(this, this.__onSelectionChanged);
		this.element.attachEvent('onchange', _selectionChangedHandler);
		
		_loadCompleteHander = Function.createDelegate(this, this.__loadComplete);
		
		if (_culture.toLowerCase() != Sys.CultureInfo.Name.toLowerCase())
		{
			this.__updateCulture();
			this.__changeSelectedOption(_culture);
		}
    }
    Jeffz.UI.CultureSelector.registerBaseMethod(this, 'initialize');
    
    this.dispose = function()
    {
        if (_selectionChangedHandler)
        {
            this.element.detachEvent('onchange', _selectionChangedHandler);
            _selectionChangedHandler = null;
            _loadCompleteHander = null;
        }
        
        Jeffz.UI.CultureSelector.callBaseMethod(this, 'dispose');
    }
    Jeffz.UI.CultureSelector.registerBaseMethod(this, 'dispose');
    
    this.__onSelectionChanged = function()
    {
		this.set_culture(this.element.options[this.element.selectedIndex].value);
    }
    
    this.__changeSelectedOption = function(culture)
    {
		var length = this.element.options.length;
		for (var i = 0; i < length; i++)
		{
			if (this.element.options[i].value.toLowerCase() == culture.toLowerCase())
			{
				this.element.selectedIndex = i;
				return;
			}
		}
    }
    
    this.__updateCulture = function()
    {
		var request = new Sys.Net.WebRequest();
		request.set_url("atlasglob.axd?c=" + _culture);
		request.completed.add(_loadCompleteHander);
		
		_isLoading = true;
		this.raisePropertyChanged('isLoading');
		
		request.invoke();
    }
    
    this.__loadComplete = function(sender)
    {
		_isLoading = false;
		this.raisePropertyChanged('isLoading');
		eval(sender.get_data());
    }
	
}
Jeffz.UI.CultureSelector.registerClass('Jeffz.UI.CultureSelector', Sys.UI.Control);
Sys.TypeDescriptor.addType('jeffz', 'cultureSelector', Jeffz.UI.CultureSelector);

Sys.CultureCancelEventArgs = function(culture) {
    Sys.CultureCancelEventArgs.initializeBase(this);
    
    var _culture = culture;
    
    this.get_culture = function()
    {
		return _culture;
    }
    
    this.getDescriptor = function() {
        var td = Sys.CultureCancelEventArgs.callBaseMethod(this, 'getDescriptor');
        td.addProperty('culture', String, true);
        return td;
    }
    Sys.CultureCancelEventArgs.registerBaseMethod(this, 'getDescriptor');
}
Sys.CultureCancelEventArgs.registerSealedClass('Sys.CultureCancelEventArgs', Sys.CancelEventArgs);